# Tegridy Raspberry Tools

***

## Everything you need for DL on Raspberry Pi but were afraid to ask for :)

***

## Install instructions for other useful and required DL packages for Raspberry Pi

### NOTE: You do not have to use sudo on most packages if you not going to run start-up scripts/do fancy stuff :)

### #===PyTorch-Keras-Tensorflow===#

sudo pip3 install pandas

sudo pip3 install dill

pip3 install --user secrets

sudo pip3 install tqdm

### #===Plotting-Displaying===#

sudo pip3 install matplotlib

sudo pip3 install ipython

### #===Music-AI===#

sudo pip3 install music21

sudo pip3 install mido

sudo pip3 install pretty_midi

sudo pip3 install fluidsynth

sudo pip3 install pyfluidsynth

sudo pip3 install midi2audio


***

#### Project Los Angeles
#### Tegridy Code 2020

